DROP TABLE "PRESCRIPTION_MEDICATION" ;
DROP TABLE "MEDICATION";
DROP TABLE "PRESCRIPTION";


CREATE table FUSION_CONFIG (
   CONF_NAME	VARCHAR2(50)	not null,
   CONF_VALUE	VARCHAR2(1000)	not null,
   CONSTRAINT PK_FUSION_CONFIG primary key (CONF_NAME)
);
CREATE table MAPPING_OBJ  (
   TARGET_OBJ	VARCHAR2(50)	not null,
   SOURCE_OBJ	VARCHAR2(50)	,
   TARGET_ATTR	VARCHAR2(50)	not null,
   SOURCE_ATTR	VARCHAR2(50)	,
   default_value	VARCHAR2(50),
   constraint PK_MAPPING_OBJ primary key (TARGET_OBJ,TARGET_ATTR)
);
 
CREATE table FUSION_SCHEDULER_JOB (
   JOB_NAME	VARCHAR2(50)	not null,
   JOB_STATUS	VARCHAR2(50),
   JOB_STARTTIME TIMESTAMP,
   JOB_INTERVAL NUMBER(10,0),
   JOB_INTERVAL_UNIT VARCHAR2(50),
   constraint PK_FUSION_SCHEDULER_JOB primary key (JOB_NAME)
);


CREATE table PRESCRIPTION 
   (	PRESCRIPTION_ID NUMBER, 
	DOCTOR_ID NUMBER, 
	PATIENT_ID NUMBER, 
	VISIT_ID NUMBER, 
	PRESCRIPTION_DATE DATE, 
	EXPIRE_DATE DATE
   );
  
CREATE TABLE MEDICATION
   (	MEDICATION_ID NUMBER, 
	NAME VARCHAR2(200 CHAR), 
	NDC_CODE NUMBER
   );

CREATE TABLE PRESCRIPTION_MEDICATION
   (	PRESCRIPTION_MEDICATION_ID NUMBER,
        PRESCRIPTION_ID NUMBER, 
	MEDICATION_ID NUMBER, 
	QUANTITY NUMBER, 
	REFILLS NUMBER, 
	PHARMACY_ID NUMBER, 
	DIRECTIONS_FOR_USE VARCHAR2(2000 CHAR), 
	IS_READY_TO_PICKUP_FL CHAR(1 CHAR) DEFAULT 'F',
	EXPIRE_DATE DATE, 
	SENT_TO_PHARMACY_FL CHAR(1 CHAR) DEFAULT 'F', 
	SENT_TO_PHARMACY_DATE DATE, 
	ORDER_NUMBER VARCHAR2(20 CHAR)
   );

create or replace procedure HealthCareBIScheduler
is
  l_clob         clob;
  l_buffer          varchar2(32767);
 
 begin
  l_clob := apex_web_service.make_rest_request(
              p_url => 'https://javatrial1316-sgoraclecorpotrial91883.java.us2.oraclecloudapps.com/HealthCare/jersey/BISchedulerJob',
              p_http_method => 'GET',
              p_username => 'JCSUser',
              p_password => 'JCSPassword'
             );
            
            l_buffer := dbms_lob.substr(l_clob, 32000, 1 );
            dbms_output.put_line(l_buffer);
end; 
/

/* 
Comment the code below to run it locally. It's only available on DBCS
*/
BEGIN
   CLOUD_SCHEDULER.CREATE_JOB (
   job_name             => 'HealthCareBISchedulerJob',
   job_type             => 'STORED_PROCEDURE',
   job_action           => 'HealthCareBIScheduler',
   start_date           => sysdate,
   repeat_interval      => 'FREQ=MINUTELY;INTERVAL=5', 
   end_date             => sysdate+365,
   enabled              =>  TRUE,
   comments             => 'Push custom object data back to OSC for BI reports');
END;
/ 



/* 
Comment the code below to run it locally. It's only available on DBCS
*/
BEGIN
   CLOUD_SCHEDULER.CREATE_JOB (
   job_name             => 'HealthCareBISchedulerJob',
   job_type             => 'STORED_PROCEDURE',
   job_action           => 'HealthCareBIScheduler',
   start_date           => sysdate,
   repeat_interval      => 'FREQ=MINUTELY;INTERVAL=5', 
   end_date             => sysdate+365,
   enabled              =>  TRUE,
   comments             => 'Push custom object data back to OSC for BI reports');
END;
/ 



--------------------------------------W----------------------------------------------------
----- PHARMACY Application  ----------------------------------------------------
---------------------------------------------------------------------------------------

DROP table P_PRESCRIPTION; 
DROP table P_HEALTHCARE_PROVIDER;
DROP table P_DRUG;  
DROP table P_DOCTOR;
DROP table P_PATIENT;



CREATE TABLE P_HEALTHCARE_PROVIDER
   (    HEALTHCARE_PROVIDER_ID NUMBER, 
       NAME VARCHAR2(200 CHAR), 
       LOCATION VARCHAR2(200 CHAR),
       TEL VARCHAR2(200 CHAR),
      FAX VARCHAR2(200 CHAR),
    CONSTRAINT PK_P_HEALTHCARE_PROVIDER primary key (HEALTHCARE_PROVIDER_ID)
   );  
  
 
CREATE TABLE P_DRUG
   (    NDC_CODE NUMBER,
        NAME VARCHAR2(200 CHAR),    
    CONSTRAINT PK_P_NDC_CODE primary key (NDC_CODE)
   ); 
  
CREATE TABLE P_PATIENT
   (    PATIENT_ID NUMBER,
        FIRST_NAME VARCHAR2(50),    
        LAST_NAME VARCHAR2(50),    
        NAME VARCHAR2(50),    
        BIRTH DATE,
    EXISTING_PATIENT CHAR(1 CHAR) DEFAULT 'F',
    INSURANCE_STATUS VARCHAR2(50),
    CONSTRAINT PK_P_PATIENT primary key (PATIENT_ID)
   );   
CREATE TABLE P_DOCTOR
(    DOCTOR_ID NUMBER,
       FIRST_NAME VARCHAR2(50),    
       LAST_NAME VARCHAR2(50),
        NAME VARCHAR2(50),    
    CONSTRAINT PK_P_DOCTOR primary key (DOCTOR_ID)
);
 
CREATE TABLE P_PRESCRIPTION
   (    ORDER_NUMBER VARCHAR2(20 CHAR),
       NDC_CODE NUMBER,
       PATIENT_ID NUMBER,
       DOCTOR_ID NUMBER,
    HEALTHCARE_PROVIDER_ID NUMBER, 
    QUANTITY NUMBER, 
    REFILLS NUMBER, 
    PHARMACY_ID NUMBER, 
    DIRECTIONS_FOR_USE VARCHAR2(2000 CHAR), 
    IS_READY_TO_PICKUP_FL CHAR(1 CHAR) DEFAULT 'F',
    EXPIRE_DATE DATE, 
    ORDER_DATE DATE,
    CONSTRAINT PK_P_PRESCRIPTION primary key (ORDER_NUMBER),
    CONSTRAINT FK_P_DOCTOR FOREIGN KEY (DOCTOR_ID) REFERENCES P_DOCTOR(DOCTOR_ID),
    CONSTRAINT FK_P_PATIENT FOREIGN KEY (PATIENT_ID) REFERENCES P_PATIENT(PATIENT_ID),
    CONSTRAINT FK_P_NDC_CODE FOREIGN KEY (NDC_CODE) REFERENCES P_DRUG(NDC_CODE),
    CONSTRAINT FK_P_HEALTHCARE_PROVIDER FOREIGN KEY (HEALTHCARE_PROVIDER_ID) REFERENCES P_HEALTHCARE_PROVIDER(HEALTHCARE_PROVIDER_ID)
   );
   

--------------------------------------W----------------------------------------------------
----- Create Medication in DataSync app  ----------------------------------------------------
---------------------------------------------------------------------------------------

INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100000','Abilify','10000');  
   

INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100001','Abilify','100001');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100002','Aciphex','100002');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100003','Actonel','100003');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100004','Actoplus MET','100004');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100005','Actos','100005');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100006','Adacel','100006');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100007','Adderall XR','100007');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100008','Advair Diskus','100008');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100009','Aggrenox','100009');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100010','Aloxi','100009');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100011','Amphetamine Salts ER','100011');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100012','Alimta','100012');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100013','AndroGel','100013');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100014','Angiomax','100013');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100015','Aranesp','100015');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100016','Asacol','100016');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100017','Atorvastatin Calcium','100017');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100018','Atripla','100018');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100019','Avapro','100019');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100020','Avastin','100020');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100021','Avelox','100021');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100022','Avodart','100022');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100023','Avonex','100023');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100024','Benicar','100024');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100025','Benicar HCT','100024');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100026','Betaseron','100026');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100027','Boniva','100027');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100028','Budesonide','100028');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100029','Byetta','100029');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100030','Bystolic','100030');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100031','Celebrex','100031');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100032','Chantix','100032');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100033','Cialis','100033');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100034','Colcrys','100034');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100035','Combivent','100035');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100036','Concerta','100036');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100037','Copaxone','100037');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100038','Crestor','100038');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100039','Cubicin','100039');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100040','Cymbalta','100040');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100041','Detrol LA','100041');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100042','Dexilant','100042');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100043','Diovan','100043');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100044','Diovan HCT','100044');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100045','Donepezil HCl','100045');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100046','Effexor XR','10000');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100047','Eloxatin','100047');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100048','Enbrel','100048');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100049','Epogen','100049');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100050','Epzicom','100050');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100051','Erbitux','100051');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100052','Evista','100052');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100053','Exelon','100053');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100054','Exforge','100054');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100055','Fentanyl','5');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100056','Flomax','100056');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100057','Flovent HFA','100057');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100058','Fluticasone Propionate','100058');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100059','Focalin XR','100059');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100060','Forteo','100059');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100061','Gammagard Liquid','100061');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100062','Gamunex-C','100062');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100063','Gardasil','100063');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100064','Geodon','100064');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100065','Gilenya','100065');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100066','Gleevec','100066');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100067','Herceptin','100067');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100068','Humalog','100068');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100069','Humalog Kwikpen','100069');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100070','Humira','100070');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100071','Incivek','100071');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100072','Invega','100072');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100073','Invega Sustenna','100073');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100074','Isentress','100074');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100075','Janumet','100075');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100076','Januvia','100076');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100077','Kaletra','100077');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100078','Lamictal','100078');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100079','Lantus','100079');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100080','Lantus Solostar','100080');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100081','Levaquin','100081');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100082','Levemir','100082');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100083','Lexapro','100083');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100084','Lexiscan','100084');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100085','Lidoderm','100085');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100086','Lialda','100086');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100087','Lipitor','100087');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100088','Loestrin 24 FE','100088');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100089','Lotrel','100089');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100090','Lovaza','100090');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100091','Lovenox','100091');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100092','Lucentis','100092');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100093','Lumigan','100093');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100094','Lunesta','100094');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100095','Lyrica','100095');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100096','Methylphenidate ER','100095');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100097','Metoprolol Succinate','100095');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100098','Mirena','100098');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100099','Namenda','100099');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100100','Nasonex','100100');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100101','Neurontin','100101');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100102','Neupogen','100102');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100103','Nexium','100103');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100104','Niaspan','100104');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100105','NovoLog','100105');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100106','Norvir','100106');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100107','NovoSeven RT','100107');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100108','Nuvaring','100108');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100109','Nutropin AQ','100109');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100110','Opana ER','100110');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100111','Orencia','100111');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100112','Ortho Tri-Cyclen Lo','100112');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100113','Oxycontin','100113');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100114','Pegasys','100114');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100115','Plavix','100115');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100116','Pneumovax 23','100116');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100117','Pradaxa','100117');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100118','Premarin','100118');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100119','Prevnar 13','100119');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100120','Prezista','100120');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100121','Pristiq','100121');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100122','Privigen','100122');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100123','Procrit','100123');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100124','Proair HFA','100124');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100125','Prograf','100125');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100126','Provigil','100126');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100127','Pulmozyme','100126');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100128','Rebif','100128');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100129','Reclast','100129');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100130','Remicade','100130');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100131','Renvela','100131');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100132','Restasis','100132');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100133','Revlimid','100133');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100134','Reyataz','100134');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100135','Risperdal Consta','100135');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100136','Rituxan','100136');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100137','Sandostatin LAR','100137');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100138','Sensipar','100138');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100139','Seroquel','100139');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100140','Seroquel XR','100140');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100141','Singulair','100141');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100142','Solodyn','100142');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100143','Spiriva Handihaler','100143');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100144','Stelara','100144');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100145','Strattera','100145');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100146','Suboxone','100146');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100147','Symbicort','100147');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100148','Synagis','100148');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100149','Synthroid','100149');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100150','Taxotere','100150');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100151','Tarceva','100151');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100152','Temodar','100152');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100153','Travatan Z','100153');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100154','Treanda','100154');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100155','Tricor','100155');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100156','Trilipix','100156');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100157','Truvada','100157');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100158','Tysabri','100158');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100159','Varivax','100159');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100160','Velcade','100160');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100161','Venlafaxine HCl ER','100161');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100162','Ventolin HFA','100162');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100163','VESIcare','100163');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100164','Viagra','100164');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100165','Victoza','100165');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100166','Viread','100166');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100167','Vytorin','100167');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100169','Vyvanse','100169');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100170','Welchol','100170');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100171','X','100171');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100172','Xeloda','100172');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100173','Xgeva','100173');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100174','Xifaxan','100174');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100175','Xolair','100175');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100176','Xopenex','100176');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100177','Yervoy','100177');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100178','Zetia','100178');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100179','Zometa','10000');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100180','Zostavax','100180');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100181','Zosyn','100181');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100182','Zyprexa','100182');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100183','Zyprexa Zydis','100183');
INSERT INTO MEDICATION (MEDICATION_ID,NAME,NDC_CODE) VALUES('100184','Zyvox','100184');





--------------------------------------W----------------------------------------------------
----- Create Medication in Pharmacyapp  ----------------------------------------------------
---------------------------------------------------------------------------------------

INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Abilify','10000');  
   

INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Abilify','100001');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Aciphex','100002');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Actonel','100003');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Actoplus MET','100004');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Actos','100005');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Adacel','100006');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Adderall XR','100007');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Advair Diskus','100008');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Aggrenox','100009');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Aloxi','100009');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Amphetamine Salts ER','100011');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Alimta','100012');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('AndroGel','100013');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Angiomax','100013');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Aranesp','100015');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Asacol','100016');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Atorvastatin Calcium','100017');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Atripla','100018');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Avapro','100019');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Avastin','100020');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Avelox','100021');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Avodart','100022');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Avonex','100023');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Benicar','100024');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Benicar HCT','100024');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Betaseron','100026');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Boniva','100027');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Budesonide','100028');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Byetta','100029');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Bystolic','100030');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Celebrex','100031');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Chantix','100032');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Cialis','100033');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Colcrys','100034');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Combivent','100035');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Concerta','100036');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Copaxone','100037');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Crestor','100038');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Cubicin','100039');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Cymbalta','100040');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Detrol LA','100041');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Dexilant','100042');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Diovan','100043');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Diovan HCT','100044');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Donepezil HCl','100045');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Effexor XR','10000');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Eloxatin','100047');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Enbrel','100048');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Epogen','100049');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Epzicom','100050');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Erbitux','100051');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Evista','100052');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Exelon','100053');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Exforge','100054');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Fentanyl','5');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Flomax','100056');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Flovent HFA','100057');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Fluticasone Propionate','100058');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Focalin XR','100059');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Forteo','100059');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Gammagard Liquid','100061');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Gamunex-C','100062');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Gardasil','100063');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Geodon','100064');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Gilenya','100065');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Gleevec','100066');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Herceptin','100067');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Humalog','100068');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Humalog Kwikpen','100069');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Humira','100070');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Incivek','100071');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Invega','100072');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Invega Sustenna','100073');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Isentress','100074');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Janumet','100075');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Januvia','100076');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Kaletra','100077');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lamictal','100078');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lantus','100079');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lantus Solostar','100080');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Levaquin','100081');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Levemir','100082');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lexapro','100083');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lexiscan','100084');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lidoderm','100085');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lialda','100086');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lipitor','100087');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Loestrin 24 FE','100088');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lotrel','100089');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lovaza','100090');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lovenox','100091');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lucentis','100092');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lumigan','100093');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lunesta','100094');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Lyrica','100095');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Methylphenidate ER','100095');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Metoprolol Succinate','100095');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Mirena','100098');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Namenda','100099');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Nasonex','100100');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Neurontin','100101');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Neupogen','100102');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Nexium','100103');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Niaspan','100104');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('NovoLog','100105');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Norvir','100106');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('NovoSeven RT','100107');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Nuvaring','100108');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Nutropin AQ','100109');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Opana ER','100110');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Orencia','100111');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Ortho Tri-Cyclen Lo','100112');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Oxycontin','100113');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Pegasys','100114');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Plavix','100115');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Pneumovax 23','100116');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Pradaxa','100117');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Premarin','100118');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Prevnar 13','100119');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Prezista','100120');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Pristiq','100121');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Privigen','100122');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Procrit','100123');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Proair HFA','100124');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Prograf','100125');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Provigil','100126');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Pulmozyme','100126');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Rebif','100128');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Reclast','100129');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Remicade','100130');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Renvela','100131');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Restasis','100132');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Revlimid','100133');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Reyataz','100134');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Risperdal Consta','100135');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Rituxan','100136');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Sandostatin LAR','100137');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Sensipar','100138');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Seroquel','100139');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Seroquel XR','100140');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Singulair','100141');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Solodyn','100142');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Spiriva Handihaler','100143');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Stelara','100144');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Strattera','100145');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Suboxone','100146');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Symbicort','100147');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Synagis','100148');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Synthroid','100149');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Taxotere','100150');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Tarceva','100151');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Temodar','100152');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Travatan Z','100153');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Treanda','100154');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Tricor','100155');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Trilipix','100156');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Truvada','100157');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Tysabri','100158');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Varivax','100159');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Velcade','100160');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Venlafaxine HCl ER','100161');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Ventolin HFA','100162');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('VESIcare','100163');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Viagra','100164');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Victoza','100165');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Viread','100166');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Vytorin','100167');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Vyvanse','100169');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Welchol','100170');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('X','100171');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Xeloda','100172');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Xgeva','100173');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Xifaxan','100174');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Xolair','100175');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Xopenex','100176');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Yervoy','100177');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Zetia','100178');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Zometa','10000');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Zostavax','100180');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Zosyn','100181');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Zyprexa','100182');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Zyprexa Zydis','100183');
INSERT INTO P_DRUG (NAME,NDC_CODE) VALUES('Zyvox','100184');





INSERT INTO P_HEALTHCARE_PROVIDER (HEALTHCARE_PROVIDER_ID,NAME,LOCATION,TEL,FAX) VALUES('1389990241668','Fusion','93 Zhong Hua Zhong Lu,New York,NY, 10017','212.234.2345','212.343.1232');
INSERT INTO P_HEALTHCARE_PROVIDER (HEALTHCARE_PROVIDER_ID,NAME,LOCATION,TEL,FAX) VALUES('1389990241718','Dixon','2355 Broadway,NV, 21223','917.234.2224,'917.111.3252');
INSERT INTO P_HEALTHCARE_PROVIDER (HEALTHCARE_PROVIDER_ID,NAME,LOCATION,TEL,FAX) VALUES('1389990241719','Oracle','600 Oracle Parkway,Redwood City, CA 94065','650.320.2321','917.111.3252');
INSERT INTO P_HEALTHCARE_PROVIDER (HEALTHCARE_PROVIDER_ID,NAME,LOCATION,TEL,FAX) VALUES('1389990241720','3600 Sansom St,MA, 10017','212.234.2345','212.343.1232');
INSERT INTO P_HEALTHCARE_PROVIDER (HEALTHCARE_PROVIDER_ID,NAME,LOCATION,TEL,FAX) VALUES('1389990241722','Orion','93 Zhong Hua Zhong Lu,New York,NY, 10017','212.234.2345','212.343.1232');
